pub fn plain_git_head_diff(
probe: &PlainGitDiffProbe,
options: &DiffOptions,
) -> Result<DiffReport>Expand description
Compute a HEAD-vs-worktree report for a plain Git repository discovered by the CLI health layer.
pub fn plain_git_head_diff(
probe: &PlainGitDiffProbe,
options: &DiffOptions,
) -> Result<DiffReport>Compute a HEAD-vs-worktree report for a plain Git repository discovered by the CLI health layer.