pub struct ContextSnippet {
pub annotation_id: String,
pub kind: String,
pub content: String,
pub revision_count: usize,
}Fields
annotation_id: Stringkind: Stringcontent: Stringrevision_count: usizeTrait Implementations
Sourceimpl Clone for ContextSnippet
impl Clone for ContextSnippet
Sourcefn clone(&self) -> ContextSnippet
fn clone(&self) -> ContextSnippet
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContextSnippet
impl Debug for ContextSnippet
Sourceimpl JsonSchema for ContextSnippet
impl JsonSchema for ContextSnippet
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ContextSnippet
impl RefUnwindSafe for ContextSnippet
impl Send for ContextSnippet
impl Sync for ContextSnippet
impl Unpin for ContextSnippet
impl UnsafeUnpin for ContextSnippet
impl UnwindSafe for ContextSnippet