pub struct FileContextEntry {
pub path: String,
pub annotations: Vec<ContextSnippet>,
}Fields
path: Stringannotations: Vec<ContextSnippet>Trait Implementations
Sourceimpl Clone for FileContextEntry
impl Clone for FileContextEntry
Sourcefn clone(&self) -> FileContextEntry
fn clone(&self) -> FileContextEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileContextEntry
impl Debug for FileContextEntry
Sourceimpl JsonSchema for FileContextEntry
impl JsonSchema for FileContextEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FileContextEntry
impl RefUnwindSafe for FileContextEntry
impl Send for FileContextEntry
impl Sync for FileContextEntry
impl Unpin for FileContextEntry
impl UnsafeUnpin for FileContextEntry
impl UnwindSafe for FileContextEntry