pub struct SemanticChangeEntry {
pub change_type: String,
pub description: String,
pub path: Option<String>,
pub from_path: Option<String>,
pub to_path: Option<String>,
pub old_name: Option<String>,
pub new_name: Option<String>,
pub importance: Option<String>,
}Fields
change_type: Stringdescription: Stringpath: Option<String>from_path: Option<String>to_path: Option<String>old_name: Option<String>new_name: Option<String>importance: Option<String>Trait Implementations
Sourceimpl Clone for SemanticChangeEntry
impl Clone for SemanticChangeEntry
Sourcefn clone(&self) -> SemanticChangeEntry
fn clone(&self) -> SemanticChangeEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticChangeEntry
impl Debug for SemanticChangeEntry
Sourceimpl From<SemanticChange> for SemanticChangeEntry
impl From<SemanticChange> for SemanticChangeEntry
Sourcefn from(change: SemanticChange) -> Self
fn from(change: SemanticChange) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for SemanticChangeEntry
impl JsonSchema for SemanticChangeEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SemanticChangeEntry
impl RefUnwindSafe for SemanticChangeEntry
impl Send for SemanticChangeEntry
impl Sync for SemanticChangeEntry
impl Unpin for SemanticChangeEntry
impl UnsafeUnpin for SemanticChangeEntry
impl UnwindSafe for SemanticChangeEntry