pub struct QueryHit {
pub seq: u64,
pub timestamp_secs: i64,
pub verb: String,
pub actor_email: String,
pub operation_id: Option<String>,
pub thread: Option<String>,
pub symbols: Vec<String>,
pub signal_kinds: Vec<String>,
pub change_id: Option<String>,
}Fields
seq: u64timestamp_secs: i64verb: Stringactor_email: Stringoperation_id: Option<String>thread: Option<String>symbols: Vec<String>signal_kinds: Vec<String>change_id: Option<String>Trait Implementations
impl Eq for QueryHit
Sourceimpl JsonSchema for QueryHit
impl JsonSchema for QueryHit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for QueryHit