pub struct ActorInfo {
pub provider: Option<String>,
pub model: Option<String>,
}Fields
provider: Option<String>model: Option<String>Trait Implementations
Sourceimpl JsonSchema for ActorInfo
impl JsonSchema for ActorInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ActorInfo
impl RefUnwindSafe for ActorInfo
impl Send for ActorInfo
impl Sync for ActorInfo
impl Unpin for ActorInfo
impl UnsafeUnpin for ActorInfo
impl UnwindSafe for ActorInfo