pub struct FastShortStatusReport {
pub subject: String,
pub health: String,
pub changes: ChangesInfo,
pub profile: FastShortStatusProfile,
}Fields
subject: Stringhealth: Stringchanges: ChangesInfoprofile: FastShortStatusProfileTrait Implementations
Sourceimpl Clone for FastShortStatusReport
impl Clone for FastShortStatusReport
Sourcefn clone(&self) -> FastShortStatusReport
fn clone(&self) -> FastShortStatusReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FastShortStatusReport
impl Debug for FastShortStatusReport
Sourceimpl JsonSchema for FastShortStatusReport
impl JsonSchema for FastShortStatusReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FastShortStatusReport
impl RefUnwindSafe for FastShortStatusReport
impl Send for FastShortStatusReport
impl Sync for FastShortStatusReport
impl Unpin for FastShortStatusReport
impl UnsafeUnpin for FastShortStatusReport
impl UnwindSafe for FastShortStatusReport