pub struct GitCheckpointInfo {
pub git_commit: String,
pub committed_at: String,
}Fields
git_commit: Stringcommitted_at: StringTrait Implementations
Sourceimpl Clone for GitCheckpointInfo
impl Clone for GitCheckpointInfo
Sourcefn clone(&self) -> GitCheckpointInfo
fn clone(&self) -> GitCheckpointInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GitCheckpointInfo
impl Debug for GitCheckpointInfo
Sourceimpl JsonSchema for GitCheckpointInfo
impl JsonSchema for GitCheckpointInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GitCheckpointInfo
impl RefUnwindSafe for GitCheckpointInfo
impl Send for GitCheckpointInfo
impl Sync for GitCheckpointInfo
impl Unpin for GitCheckpointInfo
impl UnsafeUnpin for GitCheckpointInfo
impl UnwindSafe for GitCheckpointInfo