pub struct GitOverlayHealth {
pub status: String,
pub clean: bool,
pub summary: String,
pub recovery_commands: Vec<String>,
pub checks: Vec<GitOverlayHealthCheck>,
}Fields
status: Stringclean: boolsummary: Stringrecovery_commands: Vec<String>checks: Vec<GitOverlayHealthCheck>Trait Implementations
Sourceimpl Clone for GitOverlayHealth
impl Clone for GitOverlayHealth
Sourcefn clone(&self) -> GitOverlayHealth
fn clone(&self) -> GitOverlayHealth
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GitOverlayHealth
impl Debug for GitOverlayHealth
Sourceimpl JsonSchema for GitOverlayHealth
impl JsonSchema for GitOverlayHealth
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GitOverlayHealth
impl RefUnwindSafe for GitOverlayHealth
impl Send for GitOverlayHealth
impl Sync for GitOverlayHealth
impl Unpin for GitOverlayHealth
impl UnsafeUnpin for GitOverlayHealth
impl UnwindSafe for GitOverlayHealth