pub struct MaterializedThreadInfo {
pub name: String,
pub state_id: String,
pub tree_hash_short: String,
pub file_count: usize,
pub stale: bool,
}Fields
name: Stringstate_id: Stringtree_hash_short: Stringfile_count: usizestale: boolTrait Implementations
Sourceimpl Clone for MaterializedThreadInfo
impl Clone for MaterializedThreadInfo
Sourcefn clone(&self) -> MaterializedThreadInfo
fn clone(&self) -> MaterializedThreadInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaterializedThreadInfo
impl Debug for MaterializedThreadInfo
Sourceimpl JsonSchema for MaterializedThreadInfo
impl JsonSchema for MaterializedThreadInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MaterializedThreadInfo
impl RefUnwindSafe for MaterializedThreadInfo
impl Send for MaterializedThreadInfo
impl Sync for MaterializedThreadInfo
impl Unpin for MaterializedThreadInfo
impl UnsafeUnpin for MaterializedThreadInfo
impl UnwindSafe for MaterializedThreadInfo