pub struct ParallelThreadInfo {
pub name: String,
pub coordination_status: CoordinationStatus,
pub current_state: Option<String>,
}Fields
name: Stringcoordination_status: CoordinationStatuscurrent_state: Option<String>Trait Implementations
Sourceimpl Clone for ParallelThreadInfo
impl Clone for ParallelThreadInfo
Sourcefn clone(&self) -> ParallelThreadInfo
fn clone(&self) -> ParallelThreadInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParallelThreadInfo
impl Debug for ParallelThreadInfo
Sourceimpl JsonSchema for ParallelThreadInfo
impl JsonSchema for ParallelThreadInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ParallelThreadInfo
impl RefUnwindSafe for ParallelThreadInfo
impl Send for ParallelThreadInfo
impl Sync for ParallelThreadInfo
impl Unpin for ParallelThreadInfo
impl UnsafeUnpin for ParallelThreadInfo
impl UnwindSafe for ParallelThreadInfo