pub struct RepositoryVerificationCheck {
pub name: String,
pub status: String,
pub summary: String,
pub details: BTreeMap<String, String>,
}Fields
name: Stringstatus: Stringsummary: Stringdetails: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for RepositoryVerificationCheck
impl Clone for RepositoryVerificationCheck
Sourcefn clone(&self) -> RepositoryVerificationCheck
fn clone(&self) -> RepositoryVerificationCheck
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepositoryVerificationCheck
impl Debug for RepositoryVerificationCheck
Sourceimpl JsonSchema for RepositoryVerificationCheck
impl JsonSchema for RepositoryVerificationCheck
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RepositoryVerificationCheck
impl RefUnwindSafe for RepositoryVerificationCheck
impl Send for RepositoryVerificationCheck
impl Sync for RepositoryVerificationCheck
impl Unpin for RepositoryVerificationCheck
impl UnsafeUnpin for RepositoryVerificationCheck
impl UnwindSafe for RepositoryVerificationCheck