pub struct RepositoryVerificationHealth {
pub status: String,
pub clean: bool,
pub summary: String,
pub recovery_commands: Vec<String>,
pub checks: Vec<RepositoryVerificationCheck>,
}Fields
status: Stringclean: boolsummary: Stringrecovery_commands: Vec<String>checks: Vec<RepositoryVerificationCheck>Trait Implementations
Sourceimpl Clone for RepositoryVerificationHealth
impl Clone for RepositoryVerificationHealth
Sourcefn clone(&self) -> RepositoryVerificationHealth
fn clone(&self) -> RepositoryVerificationHealth
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepositoryVerificationHealth
impl Debug for RepositoryVerificationHealth
Sourceimpl JsonSchema for RepositoryVerificationHealth
impl JsonSchema for RepositoryVerificationHealth
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RepositoryVerificationHealth
impl RefUnwindSafe for RepositoryVerificationHealth
impl Send for RepositoryVerificationHealth
impl Sync for RepositoryVerificationHealth
impl Unpin for RepositoryVerificationHealth
impl UnsafeUnpin for RepositoryVerificationHealth
impl UnwindSafe for RepositoryVerificationHealth