pub struct StateInfo {
pub change_id: String,
pub content_hash: String,
pub intent: Option<String>,
}Fields
change_id: Stringcontent_hash: Stringintent: Option<String>Trait Implementations
Sourceimpl JsonSchema for StateInfo
impl JsonSchema for StateInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StateInfo
impl RefUnwindSafe for StateInfo
impl Send for StateInfo
impl Sync for StateInfo
impl Unpin for StateInfo
impl UnsafeUnpin for StateInfo
impl UnwindSafe for StateInfo