pub struct RepositoryContextInfo {
pub kind: String,
pub parent_repository: Option<String>,
pub target_thread: Option<String>,
pub parent_thread: Option<String>,
}Fields
kind: Stringparent_repository: Option<String>target_thread: Option<String>parent_thread: Option<String>Trait Implementations
Sourceimpl Clone for RepositoryContextInfo
impl Clone for RepositoryContextInfo
Sourcefn clone(&self) -> RepositoryContextInfo
fn clone(&self) -> RepositoryContextInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepositoryContextInfo
impl Debug for RepositoryContextInfo
impl Eq for RepositoryContextInfo
Sourceimpl JsonSchema for RepositoryContextInfo
impl JsonSchema for RepositoryContextInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RepositoryContextInfo
impl PartialEq for RepositoryContextInfo
Sourcefn eq(&self, other: &RepositoryContextInfo) -> bool
fn eq(&self, other: &RepositoryContextInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RepositoryContextInfo
impl Serialize for RepositoryContextInfo
impl StructuralPartialEq for RepositoryContextInfo