pub struct RepositoryPresentation {
pub label: String,
pub context: Option<RepositoryContextInfo>,
}Fields
label: Stringcontext: Option<RepositoryContextInfo>Trait Implementations
Sourceimpl Clone for RepositoryPresentation
impl Clone for RepositoryPresentation
Sourcefn clone(&self) -> RepositoryPresentation
fn clone(&self) -> RepositoryPresentation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepositoryPresentation
impl Debug for RepositoryPresentation
impl Eq for RepositoryPresentation
Sourceimpl JsonSchema for RepositoryPresentation
impl JsonSchema for RepositoryPresentation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RepositoryPresentation
impl PartialEq for RepositoryPresentation
Sourcefn eq(&self, other: &RepositoryPresentation) -> bool
fn eq(&self, other: &RepositoryPresentation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RepositoryPresentation
impl Serialize for RepositoryPresentation
impl StructuralPartialEq for RepositoryPresentation