pub struct RepositoryVerificationState {Show 24 fields
pub verified: bool,
pub status: String,
pub repository_mode: String,
pub heddle_initialized: bool,
pub git_branch: Option<String>,
pub heddle_thread: Option<String>,
pub worktree_dirty: bool,
pub worktree_state: String,
pub import_state: String,
pub mapping_state: String,
pub remote_drift: String,
pub active_operation: Option<String>,
pub default_remote: Option<String>,
pub clone_verification: String,
pub machine_contract: String,
pub machine_contract_coverage: MachineContractCoverage,
pub workflow_status: String,
pub workflow_summary: String,
pub summary: String,
pub recommended_action: String,
pub recommended_action_template: Option<ActionTemplate>,
pub recovery_commands: Vec<String>,
pub recovery_action_templates: Vec<ActionTemplate>,
pub checks: Vec<VerificationCheck>,
}Fields
verified: boolstatus: Stringrepository_mode: Stringheddle_initialized: boolgit_branch: Option<String>heddle_thread: Option<String>worktree_dirty: boolworktree_state: Stringimport_state: Stringmapping_state: Stringremote_drift: Stringactive_operation: Option<String>default_remote: Option<String>clone_verification: Stringmachine_contract: Stringmachine_contract_coverage: MachineContractCoverageworkflow_status: Stringworkflow_summary: Stringsummary: Stringrecommended_action: Stringrecommended_action_template: Option<ActionTemplate>recovery_commands: Vec<String>recovery_action_templates: Vec<ActionTemplate>checks: Vec<VerificationCheck>Trait Implementations
Sourceimpl Clone for RepositoryVerificationState
impl Clone for RepositoryVerificationState
Sourcefn clone(&self) -> RepositoryVerificationState
fn clone(&self) -> RepositoryVerificationState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepositoryVerificationState
impl Debug for RepositoryVerificationState
impl Eq for RepositoryVerificationState
Sourceimpl JsonSchema for RepositoryVerificationState
impl JsonSchema for RepositoryVerificationState
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RepositoryVerificationState
impl PartialEq for RepositoryVerificationState
Sourcefn eq(&self, other: &RepositoryVerificationState) -> bool
fn eq(&self, other: &RepositoryVerificationState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RepositoryVerificationState