pub struct VerificationCheck {
pub name: String,
pub status: String,
pub clean: bool,
pub summary: String,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplate>,
pub recovery_commands: Vec<String>,
pub recovery_action_templates: Vec<ActionTemplate>,
pub details: BTreeMap<String, String>,
}Fields
name: Stringstatus: Stringclean: boolsummary: Stringrecommended_action: Option<String>recommended_action_template: Option<ActionTemplate>recovery_commands: Vec<String>recovery_action_templates: Vec<ActionTemplate>details: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for VerificationCheck
impl Clone for VerificationCheck
Sourcefn clone(&self) -> VerificationCheck
fn clone(&self) -> VerificationCheck
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerificationCheck
impl Debug for VerificationCheck
impl Eq for VerificationCheck
Sourceimpl JsonSchema for VerificationCheck
impl JsonSchema for VerificationCheck
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerificationCheck
impl PartialEq for VerificationCheck
Sourcefn eq(&self, other: &VerificationCheck) -> bool
fn eq(&self, other: &VerificationCheck) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VerificationCheck
impl Serialize for VerificationCheck
impl StructuralPartialEq for VerificationCheck