Embeddable Heddle facade scaffolding.
Re-exports
pub use context::ExecutionContext;pub use context::ExecutionContextBuilder;pub use context::Verbosity;pub use fsck::FsckError;pub use fsck::FsckOptions;pub use fsck::FsckReport;pub use fsck::fsck;pub use query::QueryHit;pub use query::QueryReport;pub use query::QueryRequest;pub use query::query;
Modules
- context
- Execution context shared by future facade operations.
- fsck
- Repository integrity checks.
- query
- Structured query over the operation log.
Structs
- Collecting
Warnings - Warning sink useful for embedders and tests that need to inspect warnings.
- Noop
Progress - Default progress sink for callers that do not care about progress.
- Noop
Warnings - Default warning sink for callers that do not care about warnings.
- TaskId
- Stable progress task identifier.
- Warning
- Structured warning for embedders and render layers.
Enums
- Heddle
Error - Error type for repository/storage-adjacent operations.
- Progress
Event - Structured progress event emitted by long-running operations.
Traits
- Progress
Sink - Receives structured progress events.
- Warning
Sink - Receives structured warnings that should not be printed by domain crates.