Embeddable Heddle facade scaffolding.
Re-exports
pub use context::ExecutionContext;pub use context::ExecutionContextBuilder;pub use context::Verbosity;pub use contract::HeddleReport;pub use contract::MachineOutputKind;pub use contract::OutputDiscriminator;pub use contract::ReportContract;pub use contract::schema_for_report;pub use diff::ContextSnippet;pub use diff::DiffOptions;pub use diff::DiffReport;pub use diff::DiffStats;pub use diff::FileChange;pub use diff::FileContextEntry;pub use diff::FileEolState;pub use diff::LineCounts;pub use diff::LineDiff;pub use diff::PlainGitDiffProbe;pub use diff::SemanticChangeEntry;pub use diff::SymlinkChange;pub use diff::change_line_counts;pub use diff::compute_state_diff;pub use diff::compute_tree_diff;pub use diff::diff;pub use diff::diff_worktree_status;pub use diff::plain_git_head_diff;pub use diff::render_diff_patch;pub use diff::render_diff_patch_bytes;pub use diff::should_render_modified_pair;pub use diff::trim_added_decorations_for_display;pub use diff::write_diff_patch;pub use fsck::FsckError;pub use fsck::FsckOptions;pub use fsck::FsckReport;pub use fsck::fsck;pub use query::QueryHit;pub use query::QueryReport;pub use query::QueryRequest;pub use query::query;pub use status::ActorInfo;pub use status::ChangesInfo;pub use status::CoordinationStatus;pub use status::FastShortStatusProfile;pub use status::FastShortStatusReport;pub use status::GitIndexPlan;pub use status::GitOverlayHealth;pub use status::GitOverlayHealthCheck;pub use status::GitOverlayImportHintReport;pub use status::MaterializedThreadInfo;pub use status::ParallelThreadInfo;pub use status::StateInfo;pub use status::StatusDetail;pub use status::StatusOptions;pub use status::StatusProfile;pub use status::StatusReport;pub use status::StatusThreadSummary;pub use status::assess_materialized_threads;pub use status::changes_from_worktree_status;pub use status::changes_path_count;pub use status::changes_paths;pub use status::fast_short_status_report;pub use status::status;pub use thread_shaping::CaptureSplitOptions;pub use thread_shaping::NoPathsMatchedDetails;pub use thread_shaping::ThreadMoveOptions;pub use thread_shaping::ThreadMoveOutput;pub use thread_shaping::ThreadShapingError;pub use thread_shaping::capture_split;pub use thread_shaping::thread_move;pub use verify::ActionTemplate;pub use verify::MachineContractCoverage;pub use verify::PlainGitVerifyProbe;pub use verify::RepositoryContextInfo;pub use verify::RepositoryPresentation;pub use verify::RepositoryVerificationState;pub use verify::VerificationCheck;pub use verify::VerifyOptions;pub use verify::VerifyProfile;pub use verify::VerifyReport;pub use verify::dirty_path_count;pub use verify::repository_mode_label;pub use verify::repository_presentation;pub use verify::verify;
Modules
- context
- Execution context shared by future facade operations.
- contract
- Typed machine-output contracts for embeddable Heddle reports.
- diff
- Embeddable diff facade and report model.
- fsck
- Repository integrity checks.
- query
- Structured query over the operation log.
- status
- Status facade and report contract.
- thread_
shaping - Thread capture-split and thread-move repository operations.
- verify
- Repository verification facade.
Structs
- Collecting
Warnings - Warning sink useful for embedders and tests that need to inspect warnings.
- Noop
Progress - Default progress sink for callers that do not care about progress.
- Noop
Warnings - Default warning sink for callers that do not care about warnings.
- TaskId
- Stable progress task identifier.
- Warning
- Structured warning for embedders and render layers.
Enums
- Heddle
Error - Error type for repository/storage-adjacent operations.
- Progress
Event - Structured progress event emitted by long-running operations.
Traits
- Progress
Sink - Receives structured progress events.
- Warning
Sink - Receives structured warnings that should not be printed by domain crates.